@@ -18,16 +18,15 @@
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
-#include "rt_defines.h"
 #include "rt_nonfinite.h"
 #include "rtwtypes.h"
 //#include "omp.h"
-#include "CVfast_types.h"
+#include "MAVEfast_types.h"
 
 /* Function Declarations */
 extern void b_mean(const emxArray_real_T *x, emxArray_real_T *y);
-extern void c_mean(const emxArray_real_T *x, emxArray_real_T *y);
-extern double mean(const emxArray_real_T *x);
+extern double c_mean(const emxArray_real_T *x);
+extern void mean(const emxArray_real_T *x, emxArray_real_T *y);
 
 #endif
 
